@@ -1,4 +1,4 @@
-import PyZenity
+from . import PyZenity
 
 def capture_exceptions(f):
     """Decorator which captures any exception and display it using PyZenity."""
